# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.4
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_page_sro_member_public import ResponseDataPageSROMemberPublic

class TestResponseDataPageSROMemberPublic(unittest.TestCase):
    """ResponseDataPageSROMemberPublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataPageSROMemberPublic:
        """Test ResponseDataPageSROMemberPublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataPageSROMemberPublic`
        """
        model = ResponseDataPageSROMemberPublic()
        if include_optional:
            return ResponseDataPageSROMemberPublic(
                data = sromaster.models.page[sro_member_public].Page[SROMemberPublic](
                    items = [
                        sromaster.models.sro_member_public.SROMemberPublic(
                            id = 56, 
                            registry = 'NOPRIZ', 
                            registry_id = 56, 
                            sro = sromaster.models.sro_public.SROPublic(
                                id = 56, 
                                registry_id = 56, 
                                name = '', 
                                reg_number = '', 
                                inn = 56, 
                                ogrn = 56, 
                                address = '', 
                                phone = '', 
                                email = '', 
                                website = '', 
                                members_count = 56, ), 
                            organization = sromaster.models.organization_public.OrganizationPublic(
                                id = 56, 
                                source_registry = 'NOPRIZ', 
                                inn = 56, 
                                ogrn = 56, 
                                legal_form = 'LEGAL_ENTITY', 
                                name_full = '', 
                                name_short = '', 
                                address = '', 
                                director_name = '', 
                                registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            registration_number = '', 
                            member_status = 'ACTIVE', 
                            included_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            excluded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            exclusion_reason = '', 
                            accordance_status = 'ACCORDANT', 
                            is_simple = True, 
                            is_extremely_dangerous = True, 
                            is_nuclear = True, 
                            is_odo = True, 
                            compensation_fund_fee_vv = 56, 
                            compensation_fund_fee_odo = 56, 
                            responsibility_level_vv = '', 
                            responsibility_level_odo = '', 
                            registry_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            insurances_count = 56, 
                            checks_count = 56, )
                        ], 
                    page = 56, 
                    per_page = 56, 
                    total = 56, 
                    total_pages = 56, )
            )
        else:
            return ResponseDataPageSROMemberPublic(
                data = sromaster.models.page[sro_member_public].Page[SROMemberPublic](
                    items = [
                        sromaster.models.sro_member_public.SROMemberPublic(
                            id = 56, 
                            registry = 'NOPRIZ', 
                            registry_id = 56, 
                            sro = sromaster.models.sro_public.SROPublic(
                                id = 56, 
                                registry_id = 56, 
                                name = '', 
                                reg_number = '', 
                                inn = 56, 
                                ogrn = 56, 
                                address = '', 
                                phone = '', 
                                email = '', 
                                website = '', 
                                members_count = 56, ), 
                            organization = sromaster.models.organization_public.OrganizationPublic(
                                id = 56, 
                                source_registry = 'NOPRIZ', 
                                inn = 56, 
                                ogrn = 56, 
                                legal_form = 'LEGAL_ENTITY', 
                                name_full = '', 
                                name_short = '', 
                                address = '', 
                                director_name = '', 
                                registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            registration_number = '', 
                            member_status = 'ACTIVE', 
                            included_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            excluded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            exclusion_reason = '', 
                            accordance_status = 'ACCORDANT', 
                            is_simple = True, 
                            is_extremely_dangerous = True, 
                            is_nuclear = True, 
                            is_odo = True, 
                            compensation_fund_fee_vv = 56, 
                            compensation_fund_fee_odo = 56, 
                            responsibility_level_vv = '', 
                            responsibility_level_odo = '', 
                            registry_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            insurances_count = 56, 
                            checks_count = 56, )
                        ], 
                    page = 56, 
                    per_page = 56, 
                    total = 56, 
                    total_pages = 56, ),
        )
        """

    def testResponseDataPageSROMemberPublic(self):
        """Test ResponseDataPageSROMemberPublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sromaster.models.src_models_sro_member_registry import SrcModelsSroMemberRegistry
from sromaster.models.sro_status import SROStatus
from typing import Optional, Set
from typing_extensions import Self

class SROUpsertRequest(BaseModel):
    """
    SROUpsertRequest
    """ # noqa: E501
    registry: SrcModelsSroMemberRegistry
    registry_id: StrictInt
    name: StrictStr
    reg_number: StrictStr
    inn: StrictStr
    ogrn: StrictStr
    address: StrictStr
    phone: StrictStr
    email: StrictStr
    website: Optional[StrictStr] = None
    status: Optional[SROStatus] = None
    exclusion_reason: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["registry", "registry_id", "name", "reg_number", "inn", "ogrn", "address", "phone", "email", "website", "status", "exclusion_reason"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SROUpsertRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if website (nullable) is None
        # and model_fields_set contains the field
        if self.website is None and "website" in self.model_fields_set:
            _dict['website'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if exclusion_reason (nullable) is None
        # and model_fields_set contains the field
        if self.exclusion_reason is None and "exclusion_reason" in self.model_fields_set:
            _dict['exclusion_reason'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SROUpsertRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "registry": obj.get("registry"),
            "registry_id": obj.get("registry_id"),
            "name": obj.get("name"),
            "reg_number": obj.get("reg_number"),
            "inn": obj.get("inn"),
            "ogrn": obj.get("ogrn"),
            "address": obj.get("address"),
            "phone": obj.get("phone"),
            "email": obj.get("email"),
            "website": obj.get("website"),
            "status": obj.get("status"),
            "exclusion_reason": obj.get("exclusion_reason")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.1
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "%VER%"

# Define package exports
__all__ = [
    "ParserApi",
    "UsersApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AccordanceStatus",
    "CheckDisciplinaryAction",
    "CheckResult",
    "CheckState",
    "CheckUpsertRequest",
    "HTTPValidationError",
    "InsuranceUpsertRequest",
    "LegalForm",
    "MemberStatus",
    "OrganizationSchema",
    "Registry",
    "ResponseDataUserResponse",
    "SROMemberUpsertRequest",
    "SROUpsertRequest",
    "UserResponse",
    "ValidationError",
    "ValidationErrorLocInner",
]

# import apis into sdk package
from nexium_api_client.api.parser_api import ParserApi as ParserApi
from nexium_api_client.api.users_api import UsersApi as UsersApi

# import ApiClient
from nexium_api_client.api_response import ApiResponse as ApiResponse
from nexium_api_client.api_client import ApiClient as ApiClient
from nexium_api_client.configuration import Configuration as Configuration
from nexium_api_client.exceptions import OpenApiException as OpenApiException
from nexium_api_client.exceptions import ApiTypeError as ApiTypeError
from nexium_api_client.exceptions import ApiValueError as ApiValueError
from nexium_api_client.exceptions import ApiKeyError as ApiKeyError
from nexium_api_client.exceptions import ApiAttributeError as ApiAttributeError
from nexium_api_client.exceptions import ApiException as ApiException

# import models into sdk package
from nexium_api_client.models.accordance_status import AccordanceStatus as AccordanceStatus
from nexium_api_client.models.check_disciplinary_action import CheckDisciplinaryAction as CheckDisciplinaryAction
from nexium_api_client.models.check_result import CheckResult as CheckResult
from nexium_api_client.models.check_state import CheckState as CheckState
from nexium_api_client.models.check_upsert_request import CheckUpsertRequest as CheckUpsertRequest
from nexium_api_client.models.http_validation_error import HTTPValidationError as HTTPValidationError
from nexium_api_client.models.insurance_upsert_request import InsuranceUpsertRequest as InsuranceUpsertRequest
from nexium_api_client.models.legal_form import LegalForm as LegalForm
from nexium_api_client.models.member_status import MemberStatus as MemberStatus
from nexium_api_client.models.organization_schema import OrganizationSchema as OrganizationSchema
from nexium_api_client.models.registry import Registry as Registry
from nexium_api_client.models.response_data_user_response import ResponseDataUserResponse as ResponseDataUserResponse
from nexium_api_client.models.sro_member_upsert_request import SROMemberUpsertRequest as SROMemberUpsertRequest
from nexium_api_client.models.sro_upsert_request import SROUpsertRequest as SROUpsertRequest
from nexium_api_client.models.user_response import UserResponse as UserResponse
from nexium_api_client.models.validation_error import ValidationError as ValidationError
from nexium_api_client.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.im_mailing_invoices_api import ImMailingInvoicesApi


class TestImMailingInvoicesApi(unittest.IsolatedAsyncioTestCase):
    """ImMailingInvoicesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ImMailingInvoicesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_delete_invoice_im_mailing_item_id_invoices_invoice_id_delete(self) -> None:
        """Test case for delete_invoice_im_mailing_item_id_invoices_invoice_id_delete

        Delete Invoice
        """
        pass

    async def test_finalize_invoice_im_mailing_item_id_invoices_post(self) -> None:
        """Test case for finalize_invoice_im_mailing_item_id_invoices_post

        Finalize Invoice
        """
        pass

    async def test_get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get(self) -> None:
        """Test case for get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get

        Get Invoice Download Url
        """
        pass

    async def test_get_invoice_im_mailing_item_id_invoices_invoice_id_get(self) -> None:
        """Test case for get_invoice_im_mailing_item_id_invoices_invoice_id_get

        Get Invoice
        """
        pass

    async def test_list_invoices_im_mailing_item_id_invoices_get(self) -> None:
        """Test case for list_invoices_im_mailing_item_id_invoices_get

        List Invoices
        """
        pass

    async def test_request_upload_url_im_mailing_item_id_invoices_upload_url_post(self) -> None:
        """Test case for request_upload_url_im_mailing_item_id_invoices_upload_url_post

        Request Upload Url
        """
        pass


if __name__ == '__main__':
    unittest.main()
